/*  $Id: TestSaxParser.java 1031 2010-06-15 10:28:23Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2010 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */

import org.junit.*;
import static org.junit.Assert.*;

import net.eduvax.xml.DefaultSaxParser;

import org.xml.sax.Attributes;
import java.io.FileInputStream;
import java.util.Calendar;
import java.util.Date;
import java.util.SimpleTimeZone;


public class TestSaxParser {
    @Before public void setUp() {
	    _parser=new Parser();
    }
    @After public void tearDown() {
    }
	@Test public void testParser() {
		Exception ex=null;
		try{
            Calendar cal=Calendar.getInstance();
            cal.set(2010,3,18,0,0,0);
            cal.set(Calendar.MILLISECOND,0);
            Date d3=cal.getTime();
            cal.set(2010,3,18,21,35,36);
            Date d2=cal.getTime();
            cal.set(2010,3,18,21,35,31);
            Date d1=cal.getTime();
			_parser.parse(new FileInputStream("src/test/date.xml"));
            assertEquals("Date 1",d1,_parser._d1);
            assertEquals("Date 2",d2,_parser._d2);
            assertEquals("Date 3",d3,_parser._d3);
		} 
		catch (Exception e) {
			ex=e;
			System.out.println(ex);		
			ex.printStackTrace();
		}
        assertNull("No Parser exception",ex);
	}

	private Parser _parser;

	private class Parser extends DefaultSaxParser {
        public Date _d1;
        public Date _d2;
        public Date _d3;
		/**
		 * SAX start element callback.
		 */
		public void startElement(String uri, String name,
								String qName, Attributes atts) {
			if ("root".equals(name)||"root".equals(qName)) {
				_d1=getDateAttribute(atts,"date1");
				_d2=getDateAttribute(atts,"date2");
				_d3=getDateAttribute(atts,"date3");
			}
		}
	}
}	

